==> 0.0.2.tar.gz: lib/src/image_helper.dart <==
import 'dart:io' if (dart.library.html) 'dart:html';

import 'package:flutter/material.dart';
import 'package:flutter_carousel_media_slider/carousel_media.dart';
import 'package:flutter_carousel_media_slider/src/utils.dart';

class ImageHelper extends StatelessWidget {
  const ImageHelper({
    Key? key,
    required this.carouselMedia,
    this.boxFit,
    this.placeholderImage,
  }) : super(key: key);

  final CarouselMedia carouselMedia;

  /// Box Fit for the images in the carousel.
  /// Default is [BoxFit.cover].
  final BoxFit? boxFit;

  /// Placeholder for the carousel image while images are loading from network.
  /// Default value is CircularProgressIndicator().
  final String? placeholderImage;

  @override
  Widget build(BuildContext context) {
    switch (carouselMedia.carouselImageSource) {
      case CarouselImageSource.asset:
        return Image.asset(
          carouselMedia.mediaUrl ?? '',
          width: double.infinity,
          height: double.infinity,
          errorBuilder: imageErrorWidgetBuilder,
          fit: boxFit ?? BoxFit.cover,
        );
      case CarouselImageSource.network:
        return Image.network(
          carouselMedia.mediaUrl ?? '',
          fit: boxFit ?? BoxFit.cover,
          loadingBuilder: (context, child, loadingProgress) =>
              imageLoadingBuilder(
            context,
            child,
            loadingProgress,
            placeholderImage,
          ),
          errorBuilder: imageErrorWidgetBuilder,
          width: double.infinity,
          height: double.infinity,
        );
      case CarouselImageSource.file:
        return Image.file(
          File(carouselMedia.mediaUrl ?? ''),
          width: double.infinity,
          height: double.infinity,
          errorBuilder: imageErrorWidgetBuilder,
          fit: boxFit ?? BoxFit.cover,
        );
    }
  }

  Widget imageLoadingBuilder(BuildContext context, Widget child,
      ImageChunkEvent? loadingProgress, String? placeholderImage) {
    if (loadingProgress == null) {
      return child;
    }
    return loadPlaceholder(placeholderImage);
  }
}

==> 0.0.4.tar.gz: lib/src/image_helper.dart <==
import 'dart:io';

import 'package:flutter/material.dart';
import 'package:flutter_carousel_media_slider/carousel_media.dart';
import 'package:flutter_carousel_media_slider/src/utils.dart';

class ImageHelper extends StatelessWidget {
  const ImageHelper({
    Key? key,
    required this.carouselMedia,
    this.boxFit,
    this.placeholderImage,
    required this.onError,
  }) : super(key: key);

  final CarouselMedia carouselMedia;

  /// Box Fit for the images in the carousel.
  /// Default is [BoxFit.cover].
  final BoxFit? boxFit;

  /// Placeholder for the carousel image while images are loading from network.
  /// Default value is CircularProgressIndicator().
  final Widget? placeholderImage;

  final Function onError;

  @override
  Widget build(BuildContext context) {
    switch (carouselMedia.carouselImageSource) {
      case CarouselImageSource.asset:
        return Image.asset(
          carouselMedia.mediaUrl ?? '',
          width: double.infinity,
          height: double.infinity,
          errorBuilder:
              (BuildContext context, Object exception, StackTrace? stackTrace) {
            return onError(exception).call();
          },
          fit: boxFit ?? BoxFit.cover,
        );
      case CarouselImageSource.network:
        return Image.network(
          carouselMedia.mediaUrl ?? '',
          fit: boxFit ?? BoxFit.cover,
          loadingBuilder: (context, child, loadingProgress) =>
              imageLoadingBuilder(
            context,
            child,
            loadingProgress,
            placeholderImage,
          ),
          errorBuilder:
              (BuildContext context, Object exception, StackTrace? stackTrace) {
            return onError(exception).call();
          },
          width: double.infinity,
          height: double.infinity,
        );
      case CarouselImageSource.file:
        return Image.file(
          File(carouselMedia.mediaUrl ?? ''),
          width: double.infinity,
          height: double.infinity,
          errorBuilder:
              (BuildContext context, Object exception, StackTrace? stackTrace) {
            return onError(exception).call();
          },
          fit: boxFit ?? BoxFit.cover,
        );
    }
  }

  Widget imageLoadingBuilder(BuildContext context, Widget child,
      ImageChunkEvent? loadingProgress, Widget? placeholderImage) {
    if (loadingProgress == null) {
      return child;
    }
    return loadPlaceholder(placeholderImage);
  }
}
